<?php
namespace Teknisa\TCO\Controllers;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;

class TcoEmailController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $crudService;
    protected $TcoEmailService;
    protected $dataSourceManager;
    protected $smtpUtil;
    protected $entityManager;
    protected $environment;

    public function __construct($crudService, $parameterBag, $TcoEmailService, $dataSourceManager, $smtpUtil, EntityManager $entityManager, $environment, $newCode) {
        $this->crudService       = $crudService;
        $this->parameterBag      = $parameterBag;
        $this->TcoEmailService   = $TcoEmailService;
        $this->environment       = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->smtpUtil          = $smtpUtil;
        $this->entityManager     = $entityManager;
        $this->newCode           = $newCode;
    }
    
    //Row esperada: Motivo de acordo com a especificação e NRDETALHESERVPROPCOM 
    public function enviaEmail(DTO\Request $request, DTO\Response $response = null){
        $row = $request->getRow();
        $motivo = $row['MOTIVO'];
        $assunto = "Notificação Tecfood Comercial - ";
        
        $emailParams = $this->constroiParametrosEmail();//constroi os parametros para se enviar o email
        if($motivo === 'APROVADO'){
            $dadosEmail = $this->TcoEmailService->retornaParametrosNotificacao(null, $row['NRVERSAOPROPCOM']); //retorna os parametros do email
        }
        else{
            $dadosEmail = $this->TcoEmailService->retornaParametrosNotificacao($row['NRDETALHESERVPROPCOM'], null); //retorna os parametros do email
        }
        
        if($dadosEmail){
            // validação se é para gerente ou planejamento
            if($emailParams[$motivo]['PARAPLANEJAMENTO']){//se for para equipe de planejamento
                $endereco = $this->retornarEmailGrupoPlanejadores(); // retorna todos os emails de acordo com o grupo especificado na tela de parametros
                $copia = $this->retornaEmailCopiaPlanejamento(); // retorna email que vai receber uma copia
            }else{
                if($motivo !== 'APROVADO'){
                    $endereco = $this->retornarEmailGerenteELider($row['NRDETALHESERVPROPCOM'], null);
                }
                else{
                    $endereco = $this->retornarEmailGerenteELider(null, $row['NRVERSAOPROPCOM']);
                }
                $copia = '';
            }
            
            $nrdetalheservpropcom = ($motivo === 'APROVADO') ? null : $row['NRDETALHESERVPROPCOM'];
            $assunto .= $emailParams[$motivo]['ASSUNTO'];
            $mensagem = $this->TcoEmailService->constroiMensagemParaEmail($dadosEmail, $emailParams[$motivo]['CHAVES'], $assunto, $motivo, $nrdetalheservpropcom);
            
            $this->sendMail($mensagem, $assunto, $copia, $endereco);
        }
    }
    
    //envia realmente o email
    public function sendMail($mensagem, $assunto, $copia, $endereco){
        try{
            $conditions = [
                array(
                    "columnName" => "NRORG",
                    "operator"   => '=',
                    "value"      => $this->environment->getNrOrgTrab()
                )
            ];
            $dataset = $this->crudService->getFilteredDataSet('paramtco', $conditions);
            $params = $dataset->getRows()[0];
            //Utilizar default do stmp
            //$this->smtpUtil->setHost($params['DSSERVIDORSMTP']);
            //$this->smtpUtil->setUsername($params['DSUSUARIOSMTP']);
            //$this->smtpUtil->setPassword($params['DSSENHASMTP']);
            $this->smtpUtil->setSubject($assunto);
            $this->smtpUtil->setFrom('no-reply@teknisa.com');
            $this->smtpUtil->setFromName('no-reply@teknisa.com');
            
            $success = $this->smtpUtil->sendMail($mensagem, '', $copia, $endereco);
            if($success){
                $this->gravaLogEmail($mensagem, $assunto, $endereco);
            }
            
        } catch(\Exception $e){
            throw $e;
        }
    }
    
    // retorna email que vai receber uma copia
    private function retornaEmailCopiaPlanejamento(){
        $conditions = [
            array(
                "columnName" => "NRORG",
                "operator"   => '=',
                "value"      => $this->environment->getNrOrgTrab()
            )
        ];
        $dataset = $this->crudService->getFilteredDataSet('paramtco', $conditions);
        $email = $dataset->getRows();
        return $email[0]['DSEMAILNOTIFICACAO'];
    }
    
    // retorna todos os emails de acordo com o grupo especificado na tela de parametros
    public function retornarEmailGrupoPlanejadores(){
        $listaEmails = array();
        
        $planejadores = $this->TcoEmailService->retornaEmailOperPlanejamento();
        
        foreach($planejadores as $planejador){
            if($planejador['DSEMAILOPER']){
                array_push($listaEmails, $planejador['DSEMAILOPER']);
            } 
        }
        
        return $listaEmails;
    }
    
    public function emailsRelacionadosFornecedor($cdforneced){
        $conditions = [
            array(
                "columnName" => "CDFORNECED",
                "operator"   => '=',
                "value"      => $cdforneced
            )];
        
        return $this->crudService->getFilteredDataSet('emailsRelacionadosFornecedor', $conditions);
    }

    public function enviarEmailComentario($row, $infoComentario, $emailFornecedor) {
        $mensagem = $this->TcoEmailService->getMessage($infoComentario);
        
        $this->smtpUtil->setSubject('Comentário - '.$infoComentario["NRPEDIDOCOL"]);
        $this->smtpUtil->setFrom($row["EMAIL_LOGADO"]);
        $this->smtpUtil->setFromName($row["EMAIL_LOGADO"]);
        $this->smtpUtil->sendMail($mensagem, '', '', $emailFornecedor);
    }
    
    public function retornarEmailGerenteELider($gerente, $versao){
        return $this->TcoEmailService->retornarEmailGerenteELider($gerente, $versao)[0];
    }
    
    //cria log no banco de dados para o email enviado
    private function gravaLogEmail($mensagem, $assunto, $endereco){
        $codigo = $this->newCode->getCodeByTableName('NOTIFICACAOTCO', $this->environment->getNrOrgTrab());
        $emails = join(';', $endereco);
        $notificacao = array(
            'TXNOTIFICACAO'   => $mensagem,
            'DSASSUNTO'       => $assunto,
            'DSEMAILS'        => $emails,
            'NRNOTIFICACAOTCO'=> $codigo,
            '__is_new'        => true
        );
        
        
        $request = new DTO\Request\Row($notificacao, "", "", "");
        $rows = $this->crudService->getRowsToSave($request, "notificacaotco");
        $this->crudService->save("notificacaotco", $rows);
    }
    
    private function constroiParametrosEmail(){
        return array(
            'DUVIDA' => array(
                    'ASSUNTO'          => 'Dúvida sobre Solicitação',
                    'PARAPLANEJAMENTO' => false,
                    'CHAVES' => array(
                        'CDPROPOSTACOMERCIAL' => 'Proposta Número: ',
                        'NMRAZSOCIAL'         => 'Cliente: ',
                        'NMOPERADOR'          => 'Gerente de Negócio: ',
                        'NMSERVICOPROPOSTA'   => 'Serviço: ',
                        'DSSEGMER'            => 'Segmento: ',
                        'DSATIVCLI'           => 'Ramo de Atividade: ',
                        'NMPADRAOQUALIDADE'   => 'Padrão de Qualidade: ',
                        'NMTIPOPUBLICO'       => 'Público: ',
                        'DSOBSERVACAO'        => 'Observações: '
                    )
                ),
            'DUVIDARESPONDIDA' => array(
                    'ASSUNTO'          => 'Dúvida Respondida pelo Gerente de Negócio',
                    'PARAPLANEJAMENTO' => true,
                    'CHAVES' => array(
                        'CDPROPOSTACOMERCIAL' => 'Proposta Número: ',
                        'NMRAZSOCIAL'         => 'Cliente: ',
                        'NMOPERADOR'          => 'Gerente de Negócio: ',
                        'NMSERVICOPROPOSTA'   => 'Serviço: ',
                        'DSSEGMER'            => 'Segmento: ',
                        'DSATIVCLI'           => 'Ramo de Atividade: ',
                        'NMPADRAOQUALIDADE'   => 'Padrão de Qualidade: ',
                        'NMTIPOPUBLICO'       => 'Público: ',
                        'DSOBSERVACAO'        => 'Observações: '
                    )
                ),
            'RECUSADO' => array(
                    'ASSUNTO'          => 'Solicitação Recusada',
                    'PARAPLANEJAMENTO' => false,
                    'CHAVES' => array(
                        'CDPROPOSTACOMERCIAL' => 'Proposta Número: ',
                        'NMRAZSOCIAL'         => 'Cliente: ',
                        'NMOPERADOR'          => 'Gerente de Negócio: ',
                        'NMSERVICOPROPOSTA'   => 'Serviço: ',
                        'DSSEGMER'            => 'Segmento: ',
                        'DSATIVCLI'           => 'Ramo de Atividade: ',
                        'NMPADRAOQUALIDADE'   => 'Padrão de Qualidade: ',
                        'NMTIPOPUBLICO'       => 'Público: ',
                        'DSOBSERVACAO'        => 'Observações: '
                    )
                ),
            'FINALIZADO' => array(
                    'ASSUNTO'          => 'Finalização da Solicitação',
                    'PARAPLANEJAMENTO' => false,
                    'CHAVES' => array(
                        'CDPROPOSTACOMERCIAL' => 'Proposta Número: ',
                        'NMRAZSOCIAL'         => 'Cliente: ',
                        'NMOPERADOR'          => 'Gerente de Negócio: ',
                        'NMSERVICOPROPOSTA'   => 'Serviço: ',
                        'DSSEGMER'            => 'Segmento: ',
                        'DSATIVCLI'           => 'Ramo de Atividade: ',
                        'NMPADRAOQUALIDADE'   => 'Padrão de Qualidade: ',
                        'NMTIPOPUBLICO'       => 'Público: ',
                        'DSOBSERVACAO'        => 'Observações: '
                    )
                ),
            'ERROCALCULO' => array(
                    'ASSUNTO' => 'Falha no Cálculo do Serviço',
                    'PARAPLANEJAMENTO' => true,
                    'CHAVES' => array(
                        'CDPROPOSTACOMERCIAL' => 'Proposta Número: ',
                        'NMRAZSOCIAL'         => 'Cliente: ',
                        'NMOPERADOR'          => 'Gerente de Negócio: ',
                        'NMSERVICOPROPOSTA'   => 'Serviço: ',
                        'DSSEGMER'            => 'Segmento: ',
                        'DSATIVCLI'           => 'Ramo de Atividade: ',
                        'NMPADRAOQUALIDADE'   => 'Padrão de Qualidade: ',
                        'NMTIPOPUBLICO'       => 'Público: '
                    )
                ),
            'CUSTOMIZACAO' => array(
                    'ASSUNTO'          => 'Customização da Proposta',
                    'PARAPLANEJAMENTO' => true,
                    'CHAVES' => array(
                        'CDPROPOSTACOMERCIAL' => 'Proposta Número: ',
                        'NMRAZSOCIAL'         => 'Cliente: ',
                        'NMOPERADOR'          => 'Gerente de Negócio: ',
                        'NMSERVICOPROPOSTA'   => 'Serviço: ',
                        'DSSEGMER'            => 'Segmento: ',
                        'DSATIVCLI'           => 'Ramo de Atividade: ',
                        'NMPADRAOQUALIDADE'   => 'Padrão de Qualidade: ',
                        'NMTIPOPUBLICO'       => 'Público: ',
                        'DSOBSERVACAO'        => 'Observações: '
                    )
                ),
            'EDITAL' => array(
                    'ASSUNTO'          => 'Proposta a partir de Edital',
                    'PARAPLANEJAMENTO' => true,
                    'CHAVES' => array(
                        'CDPROPOSTACOMERCIAL' => 'Proposta Número: ',
                        'NMRAZSOCIAL'         => 'Cliente: ',
                        'NMOPERADOR'          => 'Gerente de Negócio: ',
                        'NMSERVICOPROPOSTA'   => 'Serviço: ',
                        'DSSEGMER'            => 'Segmento: ',
                        'DSATIVCLI'           => 'Ramo de Atividade: ',
                        'NMPADRAOQUALIDADE'   => 'Padrão de Qualidade: ',
                        'NMTIPOPUBLICO'       => 'Público: ',
                        'DSOBSERVACAO'        => 'Observações: '
                    )
                ),
            'SERVICOCOMPLEMENTAR' => array(
                    'ASSUNTO'          => 'Serviço Complementar',
                    'PARAPLANEJAMENTO' => true,
                    'CHAVES' => array(
                        'CDPROPOSTACOMERCIAL' => 'Proposta Número: ',
                        'NMRAZSOCIAL'         => 'Cliente: ',
                        'NMOPERADOR'          => 'Gerente de Negócio: ',
                        'NMSERVICOPROPOSTA'   => 'Serviço: ',
                        'DSSEGMER'            => 'Segmento: ',
                        'DSATIVCLI'           => 'Ramo de Atividade: ',
                        'NMPADRAOQUALIDADE'   => 'Padrão de Qualidade: ',
                        'NMTIPOPUBLICO'       => 'Público: ',
                        'DSOBSERVACAO'        => 'Observações: '
                    )
                ),
            'APROVADO' => array(
                    'ASSUNTO'          => 'Aprovação da Proposta',
                    'PARAPLANEJAMENTO' => true,
                    'CHAVES' => array(
                        'CDPROPOSTACOMERCIAL' => 'Proposta Número: ',
                        'NMRAZSOCIAL'         => 'Cliente: ',
                        'NMOPERADOR'          => 'Gerente de Negócio: ',
                        'CDVERSAOPROPCOM'     => 'Simulação: '
                    )
                ),
            'SEMCARDBASE' => array(
                    'ASSUNTO'          => 'Cardápio Base não Encontrado',
                    'PARAPLANEJAMENTO' => true,
                    'CHAVES' => array(
                        'CDPROPOSTACOMERCIAL' => 'Proposta Número: ',
                        'NMRAZSOCIAL'         => 'Cliente: ',
                        'NMOPERADOR'          => 'Gerente de Negócio: ',
                        'NMSERVICOPROPOSTA'   => 'Serviço: ',
                        'DSSEGMER'            => 'Segmento: ',
                        'DSATIVCLI'           => 'Ramo de Atividade: ',
                        'NMPADRAOQUALIDADE'   => 'Padrão de Qualidade: ',
                        'NMTIPOPUBLICO'       => 'Público: ',
                        'DSOBSERVACAO'        => 'Observações: '
                    )
                )
        );
    }
}