<?php
namespace Teknisa\TCO\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\GER\Utilities\Environment;
use Teknisa\GER\Utilities\DataSourceUtil;

class Tco00200PorcionamentoService extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $entityManager;
    protected $newCode;

    public function __construct(EntityManager $entityManager, Environment $environment, $newCode) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->newCode = $newCode;
    }
    
    public function retornaPorcionamentosVinculados($porcionamento) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT MESSAGECODE,
          PARAM1,
          PARAM2,
          PARAM3,
          PARAM4
         FROM ( 
                /*Porcionamento em uso na regra de adesão __PARAM1__ do cardápio base __PARAM2__*/
                SELECT 'TCO00200_PORCIONAMENTO_EM_USO_ITEMADESAOCBASE' AS MESSAGECODE, 
                       A.CDADESAOCARDBASE || ' ' || A.NMADESAOCARDBASE AS PARAM1,
                       C.CDCARDAPIOBASE AS PARAM2,
                       NULL AS PARAM3,
                       NULL AS PARAM4
                  FROM ITEMADESAOCBASE I
                       INNER JOIN ADESAOCARDBASE A ON A.NRADESAOCARDBASE = I.NRADESAOCARDBASE
                       INNER JOIN CARDAPIOBASE C ON C.NRCARDAPIOBASE = A.NRCARDAPIOBASE
                 WHERE I.NRPORCIONAMENTO = :NRPORCIONAMENTO
                
                 UNION ALL
                
                /*Porcionamento em uso na regra de gramatura __PARAM1__ do grupo __PARAM2__ do cardápio base __PARAM3__*/
                SELECT 'TCO00200_PORCIONAMENTO_EM_USO_ITEMGRAMCARDBASE' AS MESSAGECODE,
                       TO_CHAR(G.VRGRAMATURA) || ' ' || G.SGUNIDADE AS PARAM1,
                       GR.CDGRTIPOPR || ' ' || GR.NMGRTIPOPR AS PARAM2,
                       C.CDCARDAPIOBASE AS PARAM3,
                       NULL AS PARAM4
                  FROM ITEMGRAMCARDBASE I
                       INNER JOIN GRAMATURACARDBASE G ON G.NRGRAMATURACARDBASE = I.NRGRAMATURACARDBASE
                       INNER JOIN GRTIPOPR GR ON GR.CDGRTIPOPR = G.CDGRTIPOPR
                       INNER JOIN CARDAPIOBASE C ON C.NRCARDAPIOBASE = G.NRCARDAPIOBASE
                 WHERE I.NRPORCIONAMENTO = :NRPORCIONAMENTO
                 
                 UNION ALL
                 
                 /*Porcionamento em uso no detalhe histórico ou atual no grupo __PARAM1__ do serviço __PARAM2__ da versão  __PARAM3__ da proposta comercial __PARAM4__*/
                 SELECT 'TCO00200_PORCIONAMENTO_EM_USO_CONFGRUPOTPPROPCOM' AS MESSAGECODE,
                       GR.CDGRTIPOPR || ' ' || GR.NMGRTIPOPR AS PARAM1,
                       SP.CDSERVICOPROPOSTA || ' - ' || SP.NMSERVICOPROPOSTA AS PARAM2,
                       V.CDVERSAOPROPCOM AS PARAM3,
                       P.CDPROPOSTACOMERCIAL AS PARAM4
                  FROM CONFGRUPOTPPROPCOM C
                       INNER JOIN DETALHESERVPROPCOM D ON D.NRDETALHESERVPROPCOM = C.NRDETALHESERVPROPCOM
                       INNER JOIN GRTIPOPR GR ON GR.CDGRTIPOPR = C.CDGRTIPOPR
                       INNER JOIN SERVICOPROPCOM S ON S.NRSERVICOPROPCOM = D.NRSERVICOPROPCOM
                       INNER JOIN SERVICOPROPOSTA SP ON SP.NRSERVICOPROPOSTA = S.NRSERVICOPROPOSTA
                       INNER JOIN VERSAOPROPCOM V ON V.NRVERSAOPROPCOM = S.NRVERSAOPROPCOM
                       INNER JOIN PROPOSTACOMERCIAL P ON P.NRPROPOSTACOMERCIAL = V.NRPROPOSTACOMERCIAL 
                 WHERE C.NRPORCIONAMENTO = :NRPORCIONAMENTO
                 
                 
                 UNION ALL
                 
                 /*Porcionamento em uso no tipo de prato __PARAM1__ do serviço de planejamento __PARAM2__ da unidade __PARAM3__*/
                 SELECT 'TCO00200_PORCIONAMENTO_EM_USO_CONFCARD' AS MESSAGECODE,
                        C.CDTIPOPRAT || ' - ' || T.NMTIPOPRAT AS PARAM1,
                        S.CDSERVFILI || ' - ' || S.NMSERVICO AS PARAM2,
                        C.CDFILIAL AS PARAM3,
                        NULL AS PARAM4
                   FROM CONFCARD C
                        INNER JOIN TIPOPRAT T ON T.CDTIPOPRAT = C.CDTIPOPRAT
                        INNER JOIN SERVICO S ON S.CDFILIAL = C.CDFILIAL AND
                                                S.CDSERVFILI = C.CDSERVFILI
                  WHERE C.NRPORCIONAMENTO = :NRPORCIONAMENTO
                 
          )";
        
        $query = $connection->prepare($sql);
        
        $params = array(
            'NRPORCIONAMENTO' => $porcionamento[0]['NRPORCIONAMENTO']
        ); 
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        
        return $result;
    }
    
    public function adicionarRelPorcioGrTipoPr($rows){
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        $nrorg = $this->environment->getNrOrgTrab();
        $cdoperador = $this->environment->getCdOperador();
        try {
            foreach($rows as $r){
                $existe = $this->existeRelPorcioGrTipoPr($connection, $r['NRPORCIONAMENTO'], $r['CDGRTIPOPR']);
                if(count($existe) > 0)
                    continue;
                $sql = "INSERT INTO RELPORCIOGRTIPOPR
                        (NRRELPORCIOGRTIPOPR, NRPORCIONAMENTO, CDGRTIPOPR,
                         NRORG, NRORGINCLUSAO, NRORGULTATU,
                         CDOPERINCLUSAO, CDOPERULTATU,
                         DTINCLUSAO, DTULTATU)
                        VALUES
                        (:P_NRRELPORCIOGRTIPOPR, :P_NRPORCIONAMENTO, :P_CDGRTIPOPR,
                         :P_NRORG, :P_NRORG, :P_NRORG,
                         :P_CDOPERADOR, :P_CDOPERADOR,
                         SYSDATE, SYSDATE)";
                
                $query = $connection->prepare($sql);
                $chave = $this->newCode->getCodeByTableName('RELPORCIOGRTIPOPR', $nrorg, 1, 10, true);
                $params = array(
                    'P_NRRELPORCIOGRTIPOPR' => $chave,
                    'P_NRPORCIONAMENTO' => $r['NRPORCIONAMENTO'],
                    'P_CDGRTIPOPR' => $r['CDGRTIPOPR'],
                    'P_NRORG' => $nrorg,
                    'P_CDOPERADOR' => $cdoperador
                );
                
                $query->execute($params);
            }
            $connection->commit();
        } catch (\Exception $e){
            $connection->rollback();
            throw $e;
        }
        
    }
    
    public function existeRelPorcioGrTipoPr($connection, $NRPORCIONAMENTO, $CDGRTIPOPR){
        $sql = "SELECT NRRELPORCIOGRTIPOPR
                  FROM RELPORCIOGRTIPOPR
                 WHERE NRPORCIONAMENTO = :P_NRPORCIONAMENTO
                   AND CDGRTIPOPR = :P_CDGRTIPOPR";
        
        $query = $connection->prepare($sql);
        $params = array(
            'P_NRPORCIONAMENTO' => $NRPORCIONAMENTO,
            'P_CDGRTIPOPR' => $CDGRTIPOPR
        );
        
        $result = $query->execute($params);
        $result = $query->fetchAll();
        return $result;
    }
    
    public function apagarRelPorcioGrTipoPr($rows){
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        
        try {
            foreach($rows as $r){
        
                $connection = $this->entityManager->getConnection();
                $sql = "DELETE FROM RELPORCIOGRTIPOPR
                         WHERE NRRELPORCIOGRTIPOPR = :P_NRRELPORCIOGRTIPOPR";
                
                $query = $connection->prepare($sql);
                
                $params = array(
                    'P_NRRELPORCIOGRTIPOPR' => $r['NRRELPORCIOGRTIPOPR']
                );
                
                $query->execute($params);
            }
            $connection->commit();
        } catch (\Exception $e){
            $connection->rollback();
            throw $e;
        }
        $query->execute($params);
    }
}