<?php
namespace Teknisa\TCO\Services;

use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Tco01000CardapioBaseService extends \Teknisa\GER\Controllers\TeknisaCrud{
    
    protected $crudService;
    protected $environment;
    protected $entityManager;

    public function __construct($crudService, $parameterBag, $environment, $entityManager) {
        $this->crudService = $crudService;
        $this->environment = $environment;
        $this->entityManager = $entityManager;
    }
    
    public function retornaCardapioBaseExistente($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT 'TCO01000_CARDAPIO_BASE_EXISTENTE' AS MESSAGECODE,
                       C.NRCARDAPIOBASE,
                       C.CDCARDAPIOBASE,
                       TO_CHAR(C.DTINIVIGENCIA, 'DD/MM/YYYY') AS DTINIVIGENCIA,
                       TO_CHAR(C.DTFIMVIGENCIA, 'DD/MM/YYYY') AS DTFIMVIGENCIA
                  FROM CARDAPIOBASE C
                 WHERE (C.NRSERVICOPROPOSTA = :NRSERVICOPROPOSTA)
                   AND EXISTS ( SELECT 1 
                                  FROM SEGMERCARDBASE
                                 WHERE NRCARDAPIOBASE = C.NRCARDAPIOBASE
                                   AND VALOR_NA_LISTA(CDSEGMER, :SEGMENTOS) > 0 )
                   AND (C.NRPADRAOQUALIDADE = :NRPADRAOQUALIDADE)
                   AND (C.IDATIVO = 'S')
                   AND ((C.DTINIVIGENCIA BETWEEN :DTINIVIGENCIA AND :DTFIMVIGENCIA)
                         OR (C.DTFIMVIGENCIA BETWEEN :DTINIVIGENCIA AND :DTFIMVIGENCIA)
                         OR (:DTINIVIGENCIA BETWEEN C.DTINIVIGENCIA AND C.DTFIMVIGENCIA)
                         OR (:DTFIMVIGENCIA BETWEEN C.DTINIVIGENCIA AND C.DTFIMVIGENCIA))
                   AND C.NRORG = :NRORG";
        
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRSERVICOPROPOSTA"  => isset($row["NRSERVICOPROPOSTA"]) ? $row["NRSERVICOPROPOSTA"]      : null,
            "SEGMENTOS"          => isset($row["DSSEGMER"])          ? implode("_", $row["DSSEGMER"]) : null,
            "NRPADRAOQUALIDADE"  => isset($row["NRPADRAOQUALIDADE"]) ? $row["NRPADRAOQUALIDADE"]      : null,
            "DTINIVIGENCIA"      => isset($row["DTINIVIGENCIA"])     ? $row["DTINIVIGENCIA"]          : null,
            "DTFIMVIGENCIA"      => isset($row["DTFIMVIGENCIA"])     ? $row["DTFIMVIGENCIA"]          : null,
            "NRORG"              => $this->environment->getNrOrgTrab()
        ); 
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        
        return $result;
    }

    public function defineNovoCodigoCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT MAX(TO_NUMBER(CDCARDAPIOBASE)) AS CDCARDAPIOBASE
                  FROM CARDAPIOBASE";
                  
        $query = $connection->prepare($sql);
        
        $query->execute(array());
        
        $result = $query->fetch(\PDO::FETCH_ASSOC);
        if ($result["CDCARDAPIOBASE"]) {
            $row["CDCARDAPIOBASE"] = str_pad($result["CDCARDAPIOBASE"] + 1, 10, "0", STR_PAD_LEFT);
        } else {
            $row["CDCARDAPIOBASE"] = "0000000001";
        }
    }
    
    public function retornaCardapios($filtro) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT C.NRCARDAPIOBASE,
                       C.CDCARDAPIOBASE,
                       C.NRSERVICOPROPOSTA,
                       S.NMSERVICOPROPOSTA,
                       SEGMENTO_CARDBASE(C.NRCARDAPIOBASE) AS DSSEGMER,
                       C.NRPADRAOQUALIDADE,
                       P.NMPADRAOQUALIDADE,
                       C.DTINIVIGENCIA,
                       C.DTFIMVIGENCIA,
                       C.IDATIVO,
                       C.NRORG
                  FROM CARDAPIOBASE C
                 INNER JOIN SERVICOPROPOSTA S
                    ON S.NRSERVICOPROPOSTA = C.NRSERVICOPROPOSTA
                 INNER JOIN PADRAOQUALIDADE P
                    ON P.NRPADRAOQUALIDADE   = C.NRPADRAOQUALIDADE
                 WHERE ((:CDCARDAPIOBASE IS NULL)
                    OR ( C.CDCARDAPIOBASE LIKE '%' || :CDCARDAPIOBASE || '%'))
                   AND ((:NMSERVICOPROPOSTA IS NULL) OR (VALOR_NA_LISTA(TO_CHAR(C.NRSERVICOPROPOSTA), :NMSERVICOPROPOSTA) > 0))
                   AND ((:DSSEGMER IS NULL) OR EXISTS (SELECT 1 FROM SEGMERCARDBASE 
                                                        WHERE NRCARDAPIOBASE = C.NRCARDAPIOBASE
                                                          AND VALOR_NA_LISTA(CDSEGMER, :DSSEGMER) > 0))
                   AND ((:NMPADRAOQUALIDADE IS NULL)
                    OR (VALOR_NA_LISTA(TO_CHAR(C.NRPADRAOQUALIDADE), :NMPADRAOQUALIDADE) > 0))
                   AND ((:IDATIVO                                                       = 'T')
                    OR (C.IDATIVO                                                        = :IDATIVO))
                   AND ((C.DTINIVIGENCIA BETWEEN :DTINIVIGENCIA AND :DTFIMVIGENCIA)
                         OR (C.DTFIMVIGENCIA BETWEEN :DTINIVIGENCIA AND :DTFIMVIGENCIA)
                         OR (:DTINIVIGENCIA BETWEEN C.DTINIVIGENCIA AND C.DTFIMVIGENCIA)
                         OR (:DTFIMVIGENCIA BETWEEN C.DTINIVIGENCIA AND C.DTFIMVIGENCIA))
                   AND C.NRORG = :NRORG";
        
        $query = $connection->prepare($sql);
        
        $query->execute($filtro);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function retornaOcorrenciaCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        
        $sql = "SELECT MESSAGECODE,
                       PARAM1,
                       PARAM2,
                       PARAM3
                  FROM ( /*Cardápio Base __PARAM1__ é complementar do cardápio que está sendo excluído.*/
                         SELECT 'TCO01000_CARDAPIOBASE_EM_USO_CARDCOMPLCARDBASE' AS MESSAGECODE,                
                                CARDAPIOBASE.CDCARDAPIOBASE AS PARAM1,
                                NULL AS PARAM2,
                                NULL AS PARAM3
                           FROM CARDCOMPLCARDBASE 
                          INNER JOIN CARDAPIOBASE 
                             ON CARDAPIOBASE.NRCARDAPIOBASE = CARDCOMPLCARDBASE.NRCARDAPIOBASE 
                          WHERE CARDCOMPLCARDBASE.NRCARDAPIOBASECOMPL = :NRCARDAPIOBASE 
                            AND CARDCOMPLCARDBASE.NRORG = :NRORG 
                         
                          UNION ALL
                         
                         /*Cardápio Base está em uso no serviço __PARAM1__ na versão de proposta __PARAM2__ da proposta __PARAM3__.*/
                         SELECT 'TCO01000_CARDAPIOBASE_EM_USO_SERVICOPROPCOM' AS MESSAGECODE,                
                                SERVICOPROPOSTA.CDSERVICOPROPOSTA || ' - ' || SERVICOPROPOSTA.NMSERVICOPROPOSTA AS PARAM1,
                                VERSAOPROPCOM.CDVERSAOPROPCOM AS PARAM2,
                                PROPOSTACOMERCIAL.CDPROPOSTACOMERCIAL AS PARAM3
                           FROM SERVICOPROPCOM
                          INNER JOIN SERVICOPROPOSTA
                             ON SERVICOPROPOSTA.NRSERVICOPROPOSTA = SERVICOPROPCOM.NRSERVICOPROPOSTA
                          INNER JOIN VERSAOPROPCOM
                             ON VERSAOPROPCOM.NRVERSAOPROPCOM = SERVICOPROPCOM.NRVERSAOPROPCOM
                          INNER JOIN PROPOSTACOMERCIAL
                             ON PROPOSTACOMERCIAL.NRPROPOSTACOMERCIAL = VERSAOPROPCOM.NRPROPOSTACOMERCIAL
                          WHERE SERVICOPROPCOM.NRCARDAPIOBASE = :NRCARDAPIOBASE 
                            AND SERVICOPROPCOM.NRORG = :NRORG ) ";
                            
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => isset($row["NRCARDAPIOBASE"]) ? $row["NRCARDAPIOBASE"] : null,
            "NRORG"          => $this->environment->getNrOrgTrab()
        ); 
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
        
    }
    
    public function findSegmentosMercadoCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT NRSEGMERCARDBASE,
                       NRCARDAPIOBASE,
                       CDSEGMER,
                       NRORG
                  FROM SEGMERCARDBASE
                 WHERE NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findCardapioComplementarACardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT NRCARDCOMPLCARDBASE, 
                       NRCARDAPIOBASE, 
                       NRCARDAPIOBASECOMPL,
                       NRORG
                  FROM CARDCOMPLCARDBASE
                 WHERE NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findConfiguracaoCardapioComplementarCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT CARDCOMPLCARDBASE.NRCARDAPIOBASE,
                       CARDCOMPLCARDBASE.NRCARDAPIOBASECOMPL,
                       CNFCCOMPLCARDBASE.NRCNFCCOMPLCARDBASE,
                       CNFCCOMPLCARDBASE.NRCARDCOMPLCARDBASE,
                       CNFCCOMPLCARDBASE.NRCONFIGCARDBASE,
                       CNFCCOMPLCARDBASE.NRORG
                  FROM CNFCCOMPLCARDBASE
                 INNER JOIN CARDCOMPLCARDBASE
                    ON CARDCOMPLCARDBASE.NRCARDCOMPLCARDBASE = CNFCCOMPLCARDBASE.NRCARDCOMPLCARDBASE
                 WHERE CARDCOMPLCARDBASE.NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND CARDCOMPLCARDBASE.NRORG          = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findDiaCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT NRDIACARDBASE,
                       NRCARDAPIOBASE,
                       NRORG
                  FROM DIACARDBASE
                 WHERE NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findConfiguracaoCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT NRCONFIGCARDBASE,
                       NRCARDAPIOBASE,
                       CDTIPOPRAT,
                       NRORG
                  FROM CONFIGCARDBASE
                 WHERE NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }

    public function findComposicaoCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT NRCOMPCARDBASE,
                       NRCARDAPIOBASE,
                       NRDIACARDBASE,
                       NRCONFIGCARDBASE,
                       NRORG
                  FROM COMPCARDBASE
                 WHERE NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findPratosComposicaoCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT PRATCOMPCARDBASE.NRPRATCOMPCARDBASE,
                       PRATCOMPCARDBASE.NRCOMPCARDBASE,
                       PRATCOMPCARDBASE.CDFILAUXPRAT,
                       PRATCOMPCARDBASE.CDPRATO,
                       PRATCOMPCARDBASE.NRORG
                  FROM PRATCOMPCARDBASE
                 INNER JOIN COMPCARDBASE
                    ON COMPCARDBASE.NRCOMPCARDBASE = PRATCOMPCARDBASE.NRCOMPCARDBASE 
                 WHERE COMPCARDBASE.NRCARDAPIOBASE = :NRCARDAPIOBASE 
                   AND PRATCOMPCARDBASE.NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findRegioesPratoComposicaoCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT NRREGIAOPRATCARDBASE,
                       NRPRATCOMPCARDBASE,
                       CDREGIAO,
                       NRORG
                  FROM REGIAOPRATCARDBASE
                 WHERE NRPRATCOMPCARDBASE IN (SELECT PRATCOMPCARDBASE.NRPRATCOMPCARDBASE
                                                FROM PRATCOMPCARDBASE
                                               INNER JOIN COMPCARDBASE
                                                  ON COMPCARDBASE.NRCOMPCARDBASE = PRATCOMPCARDBASE.NRCOMPCARDBASE 
                                               WHERE COMPCARDBASE.NRCARDAPIOBASE = :NRCARDAPIOBASE 
                                                 AND PRATCOMPCARDBASE.NRORG = :NRORG)";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findAdesaoCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT NRADESAOCARDBASE,
                       NRCARDAPIOBASE,
                       CDADESAOCARDBASE,
                       NMADESAOCARDBASE,
                       CDGRTIPOPR,
                       NRDIACARDBASE,
                       NRORG,
                       IDATIVO
                  FROM ADESAOCARDBASE
                 WHERE NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findSegMerAdesaoCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT ADESAOCARDBASE.NRCARDAPIOBASE,
                       SEGMERADESAOCBASE.NRSEGMERADESAOCBASE,
                       SEGMERADESAOCBASE.NRADESAOCARDBASE,
                       SEGMERADESAOCBASE.CDSEGMER,
                       SEGMERADESAOCBASE.NRORG,
                       SEGMERADESAOCBASE.IDATIVO
                  FROM SEGMERADESAOCBASE
                 INNER JOIN ADESAOCARDBASE
                    ON ADESAOCARDBASE.NRADESAOCARDBASE = SEGMERADESAOCBASE.NRADESAOCARDBASE 
                 WHERE ADESAOCARDBASE.NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND SEGMERADESAOCBASE.NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findAtivCliAdesaoCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT ADESAOCARDBASE.NRCARDAPIOBASE,
                       ATIVCLIADESAOCBASE.NRATIVCLIADESAOCBASE,
                       ATIVCLIADESAOCBASE.NRADESAOCARDBASE,
                       ATIVCLIADESAOCBASE.NRATIVCLISEGMER,
                       ATIVCLIADESAOCBASE.NRORG,
                       ATIVCLIADESAOCBASE.IDATIVO
                  FROM ATIVCLIADESAOCBASE
                 INNER JOIN ADESAOCARDBASE
                    ON ADESAOCARDBASE.NRADESAOCARDBASE = ATIVCLIADESAOCBASE.NRADESAOCARDBASE 
                 WHERE ADESAOCARDBASE.NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND ATIVCLIADESAOCBASE.NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findItemAdesaoCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT ADESAOCARDBASE.NRCARDAPIOBASE, 
                       ITEMADESAOCBASE.NRITEMADESAOCBASE,
                       ITEMADESAOCBASE.NRADESAOCARDBASE,
                       ITEMADESAOCBASE.NRCONFIGCARDBASE,
                       ITEMADESAOCBASE.NRPORCIONAMENTO,
                       ITEMADESAOCBASE.VRPEADESAO,
                       ITEMADESAOCBASE.NRORG,
                       ITEMADESAOCBASE.IDATIVO
                  FROM ITEMADESAOCBASE
                 INNER JOIN ADESAOCARDBASE
                    ON ADESAOCARDBASE.NRADESAOCARDBASE = ITEMADESAOCBASE.NRADESAOCARDBASE 
                 WHERE ADESAOCARDBASE.NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND ITEMADESAOCBASE.NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findGramaturaCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT NRGRAMATURACARDBASE,
                       NRCARDAPIOBASE,
                       CDGRTIPOPR,
                       VRGRAMATURA,
                       SGUNIDADE,
                       IDTIPOGRAMATURA,
                       NRTIPOPUBLICO,
                       NRORG,
                       IDATIVO
                  FROM GRAMATURACARDBASE
                 WHERE NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function findItemGramaturaCardapioBase($row) {
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT GRAMATURACARDBASE.NRCARDAPIOBASE,
                       ITEMGRAMCARDBASE.NRITEMGRAMCARDBASE,
                       ITEMGRAMCARDBASE.NRGRAMATURACARDBASE,
                       ITEMGRAMCARDBASE.CDGRUPPROD,
                       ITEMGRAMCARDBASE.CDSUBGRPROD,
                       ITEMGRAMCARDBASE.CDPRODUTO,
                       ITEMGRAMCARDBASE.NRPORCIONAMENTO,
                       ITEMGRAMCARDBASE.VRGRAMATURA,
                       ITEMGRAMCARDBASE.NRORG,
                       ITEMGRAMCARDBASE.IDATIVO
                  FROM ITEMGRAMCARDBASE
                 INNER JOIN GRAMATURACARDBASE
                    ON GRAMATURACARDBASE.NRGRAMATURACARDBASE = ITEMGRAMCARDBASE.NRGRAMATURACARDBASE
                 WHERE GRAMATURACARDBASE.NRCARDAPIOBASE = :NRCARDAPIOBASE
                   AND GRAMATURACARDBASE.NRORG = :NRORG";
                   
        $query = $connection->prepare($sql);
        
        $params = array(
            "NRCARDAPIOBASE" => $row["NRCARDAPIOBASE"],
            "NRORG"          => $this->environment->getNrOrgTrab()
        );
        
        $query->execute($params);
        
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return $result;
    }
    
    public function procedureTrocaPrato($row) {
        $connection = $this->entityManager->getConnection();
        
        $procedure = new StoredProcedure($connection, 'TROCAPRATO_CARDBASE');
        
        $procedure->addParam(new Param('P_NRCARDAPIOBASE',  Param::PARAM_INPUT,  $row['NRCARDAPIOBASE'],             Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_NRCARDAPIOTRAB',  Param::PARAM_INPUT,  $row["NRCARDAPIOTRAB"],             Param::PARAM_TYPE_STR)); 
        $procedure->addParam(new Param('P_NRCOMPCARDTRAB',  Param::PARAM_INPUT,  $row['NRCOMPCARDTRAB'],             Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CDREGIAO',        Param::PARAM_INPUT,  $row['CDREGIAO'],                   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRORG',           Param::PARAM_INPUT,  $this->environment->getNrOrgTrab(), Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_CDOPERADOR',      Param::PARAM_INPUT,  $this->environment->getCdoperador(),Param::PARAM_TYPE_STR));
        
        $result = $procedure->execute();
        return $result;
    }
    
    public function verifyReceCardTrabIsNew($row){
        $connection = $this->entityManager->getConnection();
        $sql = "SELECT * FROM RECEPRATCARDTRAB WHERE NRRECEPRATCARDTRAB = :NRRECEPRATCARDTRAB";
        $query = $connection->prepare($sql);
        $params = array(
            "NRRECEPRATCARDTRAB" => $row["NRRECEPRATCARDTRAB"],
        );
        $query->execute($params);
        $result = $query->fetchAll(\PDO::FETCH_ASSOC);
        return empty($result);
    }

}